﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using VGMToolbox.util;

namespace FlowerSunRainLFExt
{
    class Program
    {
        static readonly byte[] MagicBytes = new byte[] { 0x4C, 0x46 };
        
        static void Main(string[] args)
        {
            if (args.Length < 1)
            {
                Console.WriteLine("usage: FlowerSunRainLFExt.exe <filename>");
            }
            else
            {
                string filename = Path.GetFullPath(args[0]);

                using (FileStream fs = File.OpenRead(filename))
                {

                    byte[] idBytes = ParseFile.ParseSimpleOffset(fs, 0, 2);

                    if (ParseFile.CompareSegment(idBytes, 0, MagicBytes))
                    {

                        UInt16 filecount = BitConverter.ToUInt16(ParseFile.ParseSimpleOffset(fs, 2, 2), 0);

                        byte[] fileInfoRow = new byte[8];
                        int rowSize = 8;

                        long previousOffset = 0x800;
                        uint fileSize;
                        string outputPath;

                        for (int i = 0; i < filecount; i++)
                        {
                            try
                            {
                                fileInfoRow = ParseFile.ParseSimpleOffset(fs, 8 + (i * rowSize), rowSize);
                                fileSize = BitConverter.ToUInt32(fileInfoRow, 0);

                                outputPath =
                                    Path.Combine(Path.Combine(Path.GetDirectoryName(filename), Path.GetFileNameWithoutExtension(filename)),
                                        String.Format("{0}_{1}.bin", Path.GetFileNameWithoutExtension(filename), i.ToString("D4")));

                                ParseFile.ExtractChunkToFile(fs, previousOffset, (int)fileSize, outputPath, false, true);

                                Console.WriteLine(String.Format("{0}: OFFSET: 0x{1} LENGTH: 0x{2}", Path.GetFileName(outputPath), previousOffset.ToString("X8"), fileSize.ToString("X8")));

                                previousOffset += fileSize;
                            }
                            catch (Exception ex)
                            {
                                Console.WriteLine(ex.Message);
                                return;
                            }
                        } // for (int i = 0; i < filecount; i++)    
                    } 
                    else
                    {
                        Console.WriteLine("Unsupported container type.  'LF' magic bytes not found.");
                    } // if (ParseFile.CompareSegment(idBytes, 0, MagicBytes))
                } // using (FileStream fs = File.OpenRead(filename))
            } // if (args.Length < 1)
        } // Main
    }
}
